@@ -1,14 +1,11 @@
-/* $Id: base64.c,v 1.12 2004/10/08 22:33:28 m-a Exp $ */
+/* $Id: base64.c,v 1.15 2006/07/08 15:29:50 m-a Exp $ */
 
-/*****************************************************************************
-
-NAME:
-   base64.c -- decode base64 text
-
-AUTHOR:
-   David Relson <relson@osagesoftware.com>
-
-******************************************************************************/
+/** \file base64.c
+ * decode base64 encoded text
+ * \author David Relson <relson@osagesoftware.com>
+ * \author Matthias Andree <matthias.andree@gmx.de>
+ * \date 2003-2005
+ */
 
 #include "common.h"
 
@@ -25,7 +22,6 @@ static const byte base64_invalid = 0x7F;
 
 /* Function Definitions  */
 
-/** decode base64 in situ */
 uint base64_decode(word_t *word)
 {
     uint count = 0;
@@ -102,7 +98,7 @@ bool base64_validate(const word_t *word)
     for (i = 0; i < word->leng; i += 1) {
 	byte b = word->text[i];
 	byte v = base64_xlate[b];
-	if (v == 0 && b != 'A'  && b != '\n')
+	if (v == 0 && b != 'A' && b != '\n' && b != '\r')
 	    return false;
     }
 
