@@ -1,4 +1,4 @@
-/* $Id: bogotune.c,v 1.231 2006/05/29 14:28:00 relson Exp $ */
+/* $Id: bogotune.c,v 1.233 2006/07/04 11:42:38 relson Exp $ */
 
 /*****************************************************************************
 
@@ -56,6 +56,7 @@ AUTHORS:
 #include "bogoreader.h"
 #include "collect.h"
 #include "datastore.h"
+#include "longoptions.h"
 #include "msgcounts.h"
 #include "mime.h"
 #include "mxcat.h"
@@ -186,6 +187,10 @@ uint test = 0;
 bool fMakeCheck = false;	/* allows quick & dirty regression testing */
 uint cMakeCheck =    50;	/* ... for 50 cycles */
 
+/* Function Declarations */
+
+static void process_bogotune_arg(int option);
+
 /* Function Definitions */
 
 static void bt_trap(void) {}
@@ -929,6 +934,10 @@ static void help(void)
 }
 
 static struct option longopts_bogotune[] = {
+    /* longoptions.h - common options */
+    LONGOPTIONS_COMMON
+    /* longoptions.h - bogofilter/-lexer options */
+    LONGOPTIONS_LEX
     /* end of list */
     { NULL,				0, 0, 0 }
 };
@@ -936,7 +945,6 @@ static struct option longopts_bogotune[] = {
 static int process_arglist(int argc, char **argv)
 {
     int  count = 1;
-    int  lastmode = -1;
 
     bulk_mode = B_CMDLINE;
 
@@ -945,94 +953,24 @@ static int process_arglist(int argc, char **argv)
     _wildcard (&argc, &argv);	/* expand wildcards (*.*) */
 #endif
 
-#define	OPTIONS	":c:Cd:DeEM:n:qr:s:tT:vVx:"
+#define	OPTIONS	":-:c:Cd:DeEM:n:qr:s:tT:vVx:"
 
     while (1)
     {
 	int option;
+	int option_index = 0;
+	int this_option_optind = optind ? optind : 1;
+	const char *name;
 
-	option = getopt(argc, argv, "-" OPTIONS);
-	/* the "-" is a GNU getopt special to enable RETURN_IN_ORDER
-	 * behavior, i. e. nonoption arguments are returned as
-	 * option == 1 here. */
+	option = getopt_long(argc, argv, OPTIONS,
+			     longopts_bogotune, &option_index);
 
 	if (option == -1)
  	    break;
 
-	if (option == 1) {
-	    /* If getopt's RETURN_IN_ORDER behavior */
-	    switch (lastmode) {
-	    case 'n':
-	    case 's':
-		option = lastmode;
-		break;
-	    default:
-		fprintf(stderr,
-			"File names may only be given after -n or -s options.\n");
-	    }
-	}
+	name = (option_index == 0) ? argv[this_option_optind] : longopts_bogotune[option_index].name;
 
-	switch (option) {
-	case 'c':
-	    read_config_file(optarg, false, false, PR_CFG_USER, longopts_bogotune);
-	    /* FALLTHROUGH */
-	case 'C':
-	    suppress_config_file = true;
-	    break;
-	case 'd':
-	    ds_path = xstrdup(optarg);
-	    ds_flag = (ds_flag == DS_NONE) ? DS_DSK : DS_ERR;
-	    break;
-	case 'D':
-	    ds_flag = (ds_flag == DS_NONE) ? DS_RAM : DS_ERR;
-	    break;
-	case 'e':
-	    exit_zero = true;
-	    break;
-	case 'E':
-	    esf_flag ^= true;
-	    break;
-	case 'M':
-	    bogolex_file = optarg;
-	    break;
-	case 'n':
-	    lastmode = 'n';
-	    filelist_add(ham_files, optarg);
-	    break;
-	case 'q':
-	    quiet = true;
-	    break;
-	case 'r':
-	    user_robx = atof(optarg);
-	    break;
-	case 's':
-	    lastmode = 's';
-	    filelist_add(spam_files, optarg);
-	    break;
-#ifdef	TEST
-	case 't':
-	    test += 1;
-	    break;
-#endif
-	case 'T':
-	    coerced_target = atoi(optarg);
-	    break;
-	case 'v':
-	    verbose += 1;
-	    break;
-	case 'V':
-	    print_version();
-	    exit(EX_OK);
-	case 'x':
-	    if (strcmp(optarg, "MakeCheck") == 0)
-		fMakeCheck = true;
-	    else
-		set_debug_mask( optarg );
-	    break;
-	default:
-	    help();
-	    exit(EX_ERROR);
-	}
+	process_bogotune_arg(option);
     }
 
     if (ds_flag == DS_NONE)	/* default is "wordlist on disk" */
@@ -1056,6 +994,103 @@ static int process_arglist(int argc, char **argv)
     return count;
 }
 
+static void process_bogotune_arg(int option)
+{
+    static int lastmode = -1;
+
+    if (option == 1) {
+	/* If getopt's RETURN_IN_ORDER behavior */
+	switch (lastmode) {
+	case 'n':
+	case 's':
+	    option = lastmode;
+	    break;
+	default:
+	    fprintf(stderr,
+		    "File names may only be given after -n or -s options.\n");
+	}
+    }
+
+    switch (option) {
+    case 'c':
+	read_config_file(optarg, false, false, PR_CFG_USER, longopts_bogotune);
+	/* FALLTHROUGH */
+    case 'C':
+	suppress_config_file = true;
+	break;
+    case 'd':
+	ds_path = xstrdup(optarg);
+	ds_flag = (ds_flag == DS_NONE) ? DS_DSK : DS_ERR;
+	break;
+    case 'D':
+	ds_flag = (ds_flag == DS_NONE) ? DS_RAM : DS_ERR;
+	break;
+    case 'e':
+	exit_zero = true;
+	break;
+    case 'E':
+	esf_flag ^= true;
+	break;
+    case 'M':
+	bogolex_file = optarg;
+	break;
+    case 'n':
+	lastmode = 'n';
+	filelist_add(ham_files, optarg);
+	break;
+    case 'q':
+	quiet = true;
+	break;
+    case 'r':
+	user_robx = atof(optarg);
+	break;
+    case 's':
+	lastmode = 's';
+	filelist_add(spam_files, optarg);
+	break;
+#ifdef	TEST
+    case 't':
+	test += 1;
+	break;
+#endif
+    case 'T':
+	coerced_target = atoi(optarg);
+	break;
+    case 'v':
+	verbose += 1;
+	break;
+    case 'V':
+	print_version();
+	exit(EX_OK);
+    case 'x':
+	if (strcmp(optarg, "MakeCheck") == 0)
+	    fMakeCheck = true;
+	else
+	    set_debug_mask( optarg );
+	break;
+
+    case O_MAX_TOKEN_LEN:
+	max_token_len = atoi(optarg);
+	break;
+
+    case O_MIN_TOKEN_LEN:
+	min_token_len = atoi(optarg);
+	break;
+
+    case O_MAX_MULTI_TOKEN_LEN:
+	max_multi_token_len=atoi(optarg);
+	break;
+
+    case O_MULTI_TOKEN_COUNT:
+	multi_token_count=atoi(optarg);
+	break;
+
+    default:
+	help();
+	exit(EX_ERROR);
+    }
+}
+
 static double get_robx(void)
 {
     double rx;
