@@ -1,4 +1,4 @@
-/* $Id: datastore_db.c,v 1.223 2006/02/07 01:16:56 relson Exp $ */
+/* $Id: datastore_db.c,v 1.225 2006/07/02 21:38:55 relson Exp $ */
 
 /*****************************************************************************
 
@@ -34,7 +34,6 @@ Matthias Andree <matthias.andree@gmx.de> 2003 - 2005
 #include <errno.h>
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>		/* for SEEK_SET for SunOS 4.1.x */
 #include <sys/resource.h>
 #include <assert.h>
 
@@ -467,7 +466,7 @@ static bool check_fsize_limit(int fd, uint32_t pagesize) {
     struct stat st;
     struct rlimit rl;
 
-    // Only print this message once per run
+    /* Only print this message once per run */
     if (fPrinted)
 	return ok;
 
