@@ -1,4 +1,4 @@
-/* $Id: iconvert.c,v 1.12 2005/06/25 23:23:35 relson Exp $ */
+/* $Id: iconvert.c,v 1.17 2005/12/31 12:44:52 m-a Exp $ */
 
 /*****************************************************************************
 
@@ -53,8 +53,8 @@ static void iconv_print_error(int err, buff_t *src)
 	    break;
 	}
 	if (msg != NULL)
-	    fprintf(dbgout, "e: %d, %s - t: %p, r: %d, l: %d, s: %d\n", 
-		    err, msg, src->t.text, src->read, src->t.leng, src->size);
+	    fprintf(dbgout, "err: %s (%d), tx: %p, rd: %d, ln: %d, sz: %d\n",
+		    msg, err, src->t.text, src->read, src->t.leng, src->size);
     }
 }
 
@@ -76,6 +76,9 @@ static void convert(iconv_t xd, buff_t *src, buff_t *dst)
 	outbuf = (char *)dst->t.text + dst->t.leng;
 	outbytesleft = dst->size - dst->read - dst->t.leng;
 
+	if (outbytesleft == 0)
+	    break;
+
 	/*
 	 * The iconv function converts one multibyte character at a time, and for
 	 * each character conversion it increments *inbuf and decrements
@@ -151,9 +154,8 @@ static void convert(iconv_t xd, buff_t *src, buff_t *dst)
 		break;
 
 	    case E2BIG:			/* output buffer has no more room */
+					/* TODO:  Provide proper handling of E2BIG */
 		done = true;
-		if (DEBUG_ICONV(1))	/* TODO:  Provide proper handling of E2BIG */
-		    fprintf(dbgout, "E2BIG\n");
 		break;
 
 	    default:
@@ -171,7 +173,7 @@ static void convert(iconv_t xd, buff_t *src, buff_t *dst)
 
     if (DEBUG_ICONV(1) &&
 	src->t.leng != src->read)
-	fprintf(dbgout, "t: %p, r: %d, l: %d, s: %d\n", 
+	fprintf(dbgout, "tx: %p, rd: %d, ln: %d, sz: %d\n",
 		src->t.text, src->read, src->t.leng, src->size);
 }
 
