@@ -1,4 +1,4 @@
-/* $Id: maint.c,v 1.54 2005/04/04 11:16:22 relson Exp $ */
+/* $Id: maint.c,v 1.67 2005/11/23 22:56:15 m-a Exp $ */
 
 /*****************************************************************************
 
@@ -15,8 +15,14 @@ AUTHOR:
 #include <assert.h>
 #include <stdlib.h>
 
+#include "buff.h"
 #include "datastore.h"
 #include "error.h"
+#include "charset.h"
+#ifndef	DISABLE_UNICODE
+#include "convert_unicode.h"
+#include "iconvert.h"
+#endif
 #include "maint.h"
 #include "transaction.h"
 #include "wordlists.h"
@@ -30,6 +36,12 @@ size_t	 size_max = 0;
 bool     timestamp_tokens = true;
 bool	 upgrade_wordlist_version = false;
 
+#ifndef	DISABLE_UNICODE
+e_enc	 old_encoding;
+e_enc	 new_encoding;
+#define DEFAULT_OR_UNICODE(enc) (enc == E_RAW) ? charset_default : charset_unicode
+#endif
+
 /* Function Prototypes */
 
 /* Function Definitions */
@@ -132,7 +144,7 @@ bool do_replace_nonascii_characters(register byte *str, register size_t len)
 {
     bool change = false;
     assert(str != NULL);
-    while(len--) {
+    while (len--) {
 	if (*str & 0x80) {
 	    *str = '?';
 	    change = true;
@@ -182,6 +194,38 @@ static int maintain_hook(word_t *w_key, dsv_t *in_val,
 	xfree(new_token.text);
     }
 
+#ifndef	DISABLE_UNICODE
+    if (old_encoding != new_encoding)
+    {
+	buff_t new_buff;
+	buff_t old_buff;
+
+	old_buff.read = 0;
+	old_buff.size = token.leng;
+	old_buff.t.text = token.text;
+	old_buff.t.leng = token.leng;
+
+	new_buff.read = 0;
+	new_buff.size = token.leng * 6;
+	new_buff.t.leng = 0;
+	new_buff.t.text = (byte *)xmalloc(new_buff.size);
+
+	iconvert(&old_buff, &new_buff);
+
+	if (old_buff.t.leng != new_buff.t.leng ||
+	    memcmp(old_buff.t.text, new_buff.t.text, new_buff.t.leng) != 0) {
+	    if (DEBUG_ICONV(2)) {
+		fputs("***  ", dbgout); word_puts(&old_buff.t, 0, dbgout); fputs( "\n", dbgout);
+		fputs("***  ", dbgout); word_puts(&new_buff.t, 0, dbgout); fputs( "\n", dbgout);
+
+	    }
+	    merge_tokens(&old_buff.t, &new_buff.t, in_val, transaction, vhandle);
+	}
+
+	xfree(new_buff.t.text);
+    }
+#endif
+
     if (upgrade_wordlist_version)
     {
 	switch (wordlist_version)
@@ -240,6 +284,20 @@ static ex_t maintain_wordlist(void *database)
     userdata.transaction = transaction;
 
     if (DST_OK == ds_txn_begin(database)) {
+#ifndef	DISABLE_UNICODE
+	dsv_t val;
+	int rc = ds_get_wordlist_encoding(database, &val);
+	new_encoding = encoding;
+	if (rc == 0)
+	    old_encoding = val.spamcount;	/* found */
+	else
+	    old_encoding = E_RAW;		/* not found */
+	if (old_encoding != new_encoding) {
+	    const char *from_charset = DEFAULT_OR_UNICODE(old_encoding);
+	    const char *to_charset   = DEFAULT_OR_UNICODE(new_encoding);
+	    init_charset_table_iconv(from_charset, to_charset);
+	}
+#endif
 	ret = ds_foreach(database, maintain_hook, &userdata);
     } else
 	ret = EX_ERROR;
@@ -260,6 +318,22 @@ static ex_t maintain_wordlist(void *database)
 	ds_set_wordlist_version(database, &val);
     }
 
+#ifndef	DISABLE_UNICODE
+    if (old_encoding != new_encoding) {
+	dsv_t val;
+	word_t enco;
+
+	enco.text = (byte *)xstrdup(WORDLIST_ENCODING);
+	enco.leng = strlen(WORDLIST_ENCODING);
+	val.count[0] = new_encoding;
+	val.count[1] = 0;
+	val.date     = 0;
+
+	ds_write(database, &enco, &val);
+	xfree(enco.text);
+    }
+#endif
+
     if (ta_commit(transaction) != TA_OK)
 	ret = EX_ERROR;
 
@@ -269,16 +343,6 @@ static ex_t maintain_wordlist(void *database)
     return ret;
 }
 
-void maintain_wordlists(void)
-{
-    wordlist_t *list;
-
-    for (list = word_lists; list != NULL; list = list->next) {
-	maintain_wordlist(list->dsh);
-	list = list->next;
-    }
-}
-
 ex_t maintain_wordlist_file(bfpath *bfp)
 {
     ex_t rc;
