@@ -1,4 +1,4 @@
-/* $Id: register.c,v 1.41 2005/04/04 11:16:22 relson Exp $ */
+/* $Id: register.c,v 1.46 2006/11/24 08:03:34 m-a Exp $ */
 
 /* register.c -- read input with collect and register to persistent db */
 
@@ -29,9 +29,10 @@ void register_words(run_t _run_type, wordhash_t *h, u_int32_t msgcount)
     hashnode_t *node;
     wordprop_t *wordprop;
     run_t save_run_type = run_type;
-    int retrycount = 5;			/* we'll retry an aborted
-					   registration five times
+    int retrycount = 60;		/* we'll retry an aborted
+					   registration five dozen times
 					   before giving up. */
+    bool first;
 
     u_int32_t wordcount = h->count;	/* use number of unique tokens */
 
@@ -67,7 +68,17 @@ void register_words(run_t _run_type, wordhash_t *h, u_int32_t msgcount)
 
     run_type |= _run_type;
 
+    first = true;
+
 retry:
+    if (first)
+	first = false;
+    else {
+	if (verbose)
+	    fprintf(stderr, "retrying registration after avoided deadlock...\n");
+	begin_wordlist(list);
+    }
+
     if (retrycount-- == 0) {
 	fprintf(stderr, "retry count exceeded, giving up.\n");
 	exit(EX_ERROR);
@@ -138,7 +149,6 @@ retry:
 	case 0:
 	    break;
 	case DS_ABORT_RETRY:
-	    fprintf(stderr, "cannot set message count values, retrying\n");
 	    rand_sleep(4 * 1000, 1000 * 1000);
 	    goto retry;
 	default:
