@@ -1,4 +1,4 @@
-/* $Id: robx.h,v 1.1 2003/11/24 13:10:44 relson Exp $ */
+/* $Id: robx.h,v 1.3 2005/04/04 11:16:22 relson Exp $ */
 
 /*****************************************************************************
 
@@ -10,6 +10,6 @@ NAME:
 #ifndef	HAVE_ROBX_H
 #define	HAVE_ROBX_H
 
-double compute_robinson_x(char *path);
+double compute_robinson_x(void);
 
 #endif	/* HAVE_ROBX_H */
