@@ -1,4 +1,4 @@
-/* $Id: rstats.c,v 1.51 2005/03/15 12:25:59 relson Exp $ */
+/* $Id: rstats.c,v 1.55 2006/07/02 21:38:10 relson Exp $ */
 
 /*****************************************************************************
 
@@ -228,24 +228,25 @@ static void rstats_print_histogram(size_t robn, rstats_t **rstats_array, size_t
 static void rstats_print_rtable(rstats_t **rstats_array, size_t count)
 {
     size_t r;
+    const char *pfx = !stats_in_header ? "" : "  ";
 
     /* print header */
     if (!Rtable)
-	(void)fprintf(fpo, "%*s %6s    %-6s    %-6s    %-6s %s\n",
-		      MAXTOKENLEN+2,"","n", "pgood", "pbad", "fw", "U");
+	(void)fprintf(fpo, "%s%*s %6s    %-6s    %-6s    %-6s %s\n",
+		      pfx, max_token_len+2,"","n", "pgood", "pbad", "fw", "U");
     else
-	(void)fprintf(fpo, "%*s %6s    %-6s    %-6s    %-6s  %-6s    %-6s %s\n",
-		      MAXTOKENLEN+2,"","n", "pgood", "pbad", "fw","invfwlog", "fwlog", "U");
+	(void)fprintf(fpo, "%s%*s %6s    %-6s    %-6s    %-6s  %-6s    %-6s %s\n",
+		      pfx, max_token_len+2,"","n", "pgood", "pbad", "fw","invfwlog", "fwlog", "U");
 
     /* Print 1 line per token */
     for (r= 0; r<count; r+=1)
     {
 	rstats_t *cur = rstats_array[r];
-	int len = max(0, MAXTOKENLEN-(int)cur->token->leng);
+	int len = (cur->token->leng >= max_token_len) ? 0 : (max_token_len - cur->token->leng);
 	double fw = calc_prob(cur->good, cur->bad, cur->msgs_good, cur->msgs_bad);
 	char flag = (fabs(fw-EVEN_ODDS) - min_dev >= EPS) ? '+' : '-';
 
-	(void)fputc( '"', fpo);
+	(void)fprintf(fpo, "%s\"", pfx);
 	(void)word_puts(cur->token, 0, fpo);
 
 	if (cur->msgs_good == 0 && cur->msgs_bad == 0)
@@ -264,11 +265,11 @@ static void rstats_print_rtable(rstats_t **rstats_array, size_t count)
 			  fw);
 
 	if (Rtable)
-	    (void)fprintf(fpo, "%10.5f%10.5f",
-			  log(1.0 - fw), log(fw));
+	    (void)fprintf(fpo, "%s%10.5f%10.5f",
+			  pfx, log(1.0 - fw), log(fw));
 	(void)fprintf(fpo, " %c\n", flag);
     }
 
     /* print trailer */
-    msg_print_summary();
+    msg_print_summary(pfx);
 }
