@@ -1,4 +1,4 @@
-/* $Id: sighandler.c,v 1.5 2005/06/04 13:00:55 relson Exp $ */
+/* $Id: sighandler.c,v 1.7 2006/07/03 00:21:29 relson Exp $ */
 
 /*****************************************************************************
 
@@ -13,7 +13,6 @@ AUTHOR:
 #include "common.h"
 
 #include <signal.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
 
@@ -54,7 +53,7 @@ static void mysigdie(int sig)
 
 void signal_setup(void)
 {
-    mysignal(SIGINT,  mysigdie);
-    mysignal(SIGPIPE, SIG_IGN);
-    mysignal(SIGTERM, mysigdie);
+    mysignal(SIGINT,  mysigdie);	/*  2 */
+    mysignal(SIGPIPE, SIG_IGN);		/*  1 */
+    mysignal(SIGTERM, mysigdie);	/* 15 */
 }
