@@ -1,4 +1,4 @@
-/* $Id: system.c,v 1.16 2004/08/07 12:31:29 relson Exp $ */
+/* $Id: system.c,v 1.17 2006/05/29 14:28:00 relson Exp $ */
 
 /*****************************************************************************
 
@@ -30,8 +30,6 @@ const char *const system_config_file = "<Bogofilter$Dir>.bogofilter/cf";
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
-/* some broken systems define it in unistd.h instead */
-#include <unistd.h>
 
 /** Checks if \a path is absolute. */
 bool bf_abspath(const char *path /** path to check for absoluteness */)
