@@ -1,4 +1,4 @@
-/* $Id: token.h,v 1.18 2004/07/15 00:56:19 m-a Exp $ */
+/* $Id: token.h,v 1.22 2006/06/20 22:22:00 relson Exp $ */
 
 /*****************************************************************************
 
@@ -12,17 +12,18 @@ NAME:
 
 #include "lexer.h"
 
-extern word_t *yylval;
 extern word_t *msg_addr;	/* First IP Address in Received: statement */
 extern word_t *msg_id;		/* Message ID */
 extern word_t *queue_id;	/* Message's first Queue ID */
 
-extern token_t get_token(void);
+extern token_t get_token(word_t *token);
 
 extern void got_from(void);
 extern void clr_tag(void);
 extern void set_tag(const char *text);
 
+extern void set_msg_id(byte *text, uint leng);
+
 extern void token_init(void);
 extern void token_cleanup(void);
 
