@@ -1,4 +1,4 @@
-/* $Id: xmalloc.h,v 1.6 2004/02/24 18:39:16 m-a Exp $ */
+/* $Id: xmalloc.h,v 1.8 2005/03/16 00:52:05 relson Exp $ */
 
 #ifndef XMALLOC_H
 #define XMALLOC_H
@@ -6,7 +6,6 @@
 #include <stddef.h>
 #include <stdlib.h>
 
-#ifdef	BF_MALLOC
 /* special defines for xmalloc.c, xcalloc.c, etc */
 #ifndef	ENABLE_MEMDEBUG
   #define bf_malloc  malloc
@@ -16,7 +15,6 @@
 #else
   #include "memdebug.h"
 #endif
-#endif
 
 /*@noreturn@*/
 /** print out of memory error and exit program */
@@ -49,7 +47,7 @@ void xfree(/*@only@*/ /*@null@*/ void *ptr);
 void *xcalloc(size_t nmemb, size_t size);
 
 /** reallocate \a size bytes of memory and initialize it with the
- * first bytes of the shorter area (old in \a ptr vs. newly allocated),
+ * first bytes of the shorter area (old in \a ptr vs.\ newly allocated),
  * exit program on allocation failure */
 /*@only@*/ /*@out@*/ /*@notnull@*/
 void *xrealloc(/*@only@*/ void *ptr, size_t size);
